==> benno-web-2.8.20.tgz: srv/benno/bennoweb/htdocs/ctrl/storeQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'model/StoredQuery.php';
$extForm   = $App->getParam('ext');
$queryName = $App->getParam('queryName');
$queryName = urldecode($queryName);         // "..." will be url-encoded

$USER = $App->getSession('USER');
$queryId = uniqid($USER->id);

$ExtQuery = new Query($queryId,$archive,
        $extForm['text'],
        DateConvert::Date2Timestamp($extForm['dateFrom'],$App->date_format),
        DateConvert::Date2Timestamp($extForm['dateTo'],$App->date_format),
        $extForm['sender'],
        $extForm['recipient'],
        $extForm['subject'],
        $extForm['headerName'],
        $extForm['headerValue'],
        isset($extForm['isAttachment']),
        isset($extForm['isSpam'])
    );
$ExtQuery->type = $searchMaskState;
$ExtQuery->setSortOrder($sortOrder);

$App->setSession('isSpam',@$extForm['isSpam']);

try {
    // store query
    $StoredQuery = new StoredQuery($queryId,$USER->id,$queryName,$ExtQuery);
    $StoredQuery->save();
    $QueryList = StoredQuery::FetchList($USER->id);
    $App->setSession('QueryList',$QueryList);
}
catch (Exception $e) {
    $App->log('[storeQuery] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

# response without html header and footer
$App->view = 'showList';

?>

==> benno-web-2.10.4.tgz: srv/benno/bennoweb/htdocs/ctrl/storeQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'model/StoredQuery.php';
$extForm   = $App->getParam('ext');
$queryName = $App->getParam('queryName');
$queryName = urldecode($queryName);         // "..." will be url-encoded

$USER = $App->getSession('USER');
$queryId = uniqid($USER->id);

$ExtQuery = new Query($queryId,
        $extForm['text'],
        DateConvert::Date2Timestamp($extForm['dateFrom'],$App->date_format),
        DateConvert::Date2Timestamp($extForm['dateTo'],$App->date_format),
        $extForm['sender'],
        $extForm['recipient'],
        $extForm['subject'],
        $extForm['headerName'],
        $extForm['headerValue'],
        isset($extForm['isAttachment']),
        isset($extForm['isSpam'])
    );
$ExtQuery->type = $searchMaskState;
$ExtQuery->setSortOrder($sortOrder);

$App->setSession('isSpam',@$extForm['isSpam']);

try {
    // store query
    $StoredQuery = new StoredQuery($queryId,$USER->id,$queryName,$ExtQuery);
    $StoredQuery->save();
    $QueryList = StoredQuery::FetchList($USER->id);
    $App->setSession('QueryList',$QueryList);
}
catch (Exception $e) {
    $App->log('[storeQuery] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

# response without html header and footer
$App->view = 'showList';

?>
